@@ -1,4 +1,5 @@
 from .colored import Colored
-from .style import WarnStyle, NormalStyle
+from .style import NormalStyle, WarnStyle
+
 warn = Colored(WarnStyle)
 normal = Colored(NormalStyle)
