@@ -23,10 +23,7 @@ def ensure_gh_token(token: str):
     Raise token error if token is valid by requesting github
     """
     httpx_headers = httpx.Headers(
-        {
-            "User-Agent": "GitHubClassroomUtils/1.0",
-            "Authorization": f"token {token}",
-        }
+        {"User-Agent": "GitHubClassroomUtils/1.0", "Authorization": f"token {token}",}
     )
     res = httpx.get("https://api.github.com/user", headers=httpx_headers)
     if res.status_code != 200:
